@@ -3,4 +3,4 @@ from .ImageDataLoader import ImageDataLoader
 from .Helper import Helper
 from .Trainer import Trainer, TrainerConfig, CheckpointCallback
 
-__all__ = ["ImageDataLoader", "Helper", "Trainer", :"TrainerConfig", "CheckpointCallback"]
\ No newline at end of file
+__all__ = ["ImageDataLoader", "Helper", "Trainer", "TrainerConfig", "CheckpointCallback"]
\ No newline at end of file
